@@ -5,12 +5,14 @@
  * specification next to your coffee ;-)
  */
 
-#include "config.h"
+#include "mem_config.h"
 
 #include <cassert>
 #include <sys/types.h>
 #include <cstdio>
-#include <unistd.h>
+#if HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
 #include <fcntl.h>
 #include <cerrno>
 #include <cstdlib>
